@@ -1,15 +1,18 @@
 #!/bin/bash
 # PHP-5.2	(http://www.php.net)
 #	BuildScript for Plamo Linux 4.7
-#			by Jun Kuwamura <juk@linet.gr.jp> on 2009-09-18
+#			by Jun Kuwamura <juk@linet.gr.jp> on 2010-07-27
 # require:
 HTTPD_VER=2.2.14
 HTTPD=httpd-$HTTPD_VER
 #	postgresql-8.4.x
 #	re2c-0.12.2
 #PHP
-VERSION=5.2.12
+VERSION=5.2.14
 #VERSION=5.2.7RC4
+
+REL=P1
+
 #SUHOSIN
 # ex. http://download.suhosin.org/suhosin-0.9.27.tgz
 SUHOSIN=suhosin-0.9.29
@@ -37,7 +40,6 @@ fi
 #MBPAT_FILE=mbstring-jpr-25298-20050414.patch.diff.gz
 #MBPAT_URI=http://www.voltex.jp/patches/$MBPAT_FILE
 
-REL=P1
 CPU=i586
 SYS_NAME="${CPU}-${REL}"
 
@@ -130,7 +132,7 @@ fi
   --enable-exif --enable-soap --enable-sockets --with-zlib \
   --enable-sysvmsg --enable-sysvsem --enable-sysvshm --enable-shmop \
   --with-readline --enable-ftp --with-openssl \
-  --with-pgsql  --with-pdo-pgsql=/opt/pgsql \
+  --with-pgsql --with-pdo-pgsql=/opt/pgsql \
   --enable-sqlite-utf8
 
 #  #--with-config-file-scan-dir
@@ -177,7 +179,8 @@ ZTS=`sh ./scripts/php-config --extension-dir`
 
  cd ext/gd
    phpize
-   LIBS=" -lz -lm " ./configure --enable-gd-native-ttf --enable-gd-jis-conv --with-freetype-dir=/usr/X11R7 --with-xpm-dir=/usr/X11R7 --with-jpeg-dir=/usr --with-png-dir=/usr  --with-zlib-dir=/usr
+   LIBS=" -lz -lm " ./configure --enable-gd-native-ttf --enable-gd-jis-conv --with-jpeg-dir=/usr --with-png-dir=/usr  --with-zlib-dir=/usr
+   # --with-freetype-dir=/usr/X11R7 --with-xpm-dir=/usr/X11R7
 
    make; make install
    cat >> ../extpkg.lis<<__EOFgd
@@ -460,6 +463,12 @@ __EOFapc
 $ZTS/apd.so
 __EOFapd
 
+# FileInfo
+ pecl install fileinfo
+ cat >> ../../ext/extpkg.lis<<__EOFfileinfo
+$ZTS/fileinfo.so
+__EOFfileinfo
+
 
 # Namazu
 wget -N http://osdn.dl.sourceforge.jp/php-i18n/14174/namazu-2.3.1.tgz
@@ -471,7 +480,6 @@ cd namazu-2.3.1/
   cat >> ../../ext/extpkg.lis<<__EOFnamazu
 $ZTS/namazu.so
 __EOFnamazu
-
    cd ..
 
 
@@ -486,7 +494,6 @@ cd $SUHOSIN/
   cat >> ../../ext/extpkg.lis<<__EOFsuhosin
 $ZTS/suhosin.so
 __EOFsuhosin
-
   cd ..
 fi #SUHOSIN
 
@@ -502,9 +509,10 @@ __EOFuploadprogress
 $ZTS/bcompiler.so
 __EOFbcompiler
 
-cd ..
 pwd
 
+cd ${CWD}/${PAC_NAME}
+
 mkdir -p $WORK/$DOC_DIR
 cp -p $BUILD_DIR/`basename $0`  \
       CODING_STANDARDS CREDITS EXTENSIONS INSTALL LICENSE NEWS UPGRADING  \
